@@ -48,7 +48,7 @@ member_plot <- function(x) {
   
   plot_dat <- 
     dat %>% 
-    dplyr::select(penalty, .config, mean, .metric) 
+    dplyr::select(penalty, mixture, .config, mean, .metric) 
   
   memb_data <- 
     dplyr::filter(plot_dat, .metric == "num_members") %>% 
@@ -57,10 +57,19 @@ member_plot <- function(x) {
   
   other_metrics <- dplyr::filter(plot_dat, .metric != "num_members")
   
-  plot_dat <- dplyr::full_join(memb_data, other_metrics, by = c("penalty", ".config"))
+  plot_dat <- dplyr::full_join(memb_data, other_metrics, by = c("penalty", "mixture", ".config"))
+  
+  mult_mix <- length(unique(plot_dat$mixture)) > 1
+  
+  if (mult_mix) {
+    plot_dat$mixture <- format(plot_dat$mixture)
+    p <- ggplot2::ggplot(plot_dat, ggplot2::aes(x = num_members, y = mean, col = mixture)) 
+  } else {
+    p <- ggplot2::ggplot(plot_dat, ggplot2::aes(x = num_members, y = mean)) 
+  }
   
   p <- 
-    ggplot2::ggplot(plot_dat, ggplot2::aes(x = num_members, y = mean)) +
+    p + 
     ggplot2::geom_point() + 
     ggplot2::facet_wrap(
       ~.metric, 
@@ -74,8 +83,17 @@ member_plot <- function(x) {
 
 performance_plot <- function(x) {
   dat <- x$metrics
+  mult_mix <- length(unique(dat$mixture)) > 1
+  
+  if (mult_mix) {
+    dat$mixture <- format(dat$mixture)
+    p <- ggplot2::ggplot(dat, ggplot2::aes(x = penalty, y = mean, col = mixture)) 
+  } else {
+    p <- ggplot2::ggplot(dat, ggplot2::aes(x = penalty, y = mean)) 
+  }
   p <- 
-    ggplot2::ggplot(dat, ggplot2::aes(x = penalty, y = mean)) +
+    p + 
+    ggplot2::geom_vline(xintercept = x$penalty$penalty, lty = 2) +
     ggplot2::geom_point() + 
     ggplot2::geom_path() + 
     ggplot2::facet_wrap(~ .metric, scales = "free_y", ncol = 1) + 
@@ -92,7 +110,7 @@ weights_plot <- function(x, penalty = x$penalty$penalty, n = Inf) {
     dat_order <- 
       dat %>% 
       dplyr::group_by(model, terms) %>% 
-      dplyr::summarize(mean = max(weight, na.rm = TRUE)) %>% 
+      dplyr::summarize(mean = max(abs(weight), na.rm = TRUE)) %>% 
       dplyr::ungroup() %>% 
       dplyr::arrange(mean) %>% 
       dplyr::mutate(member = dplyr::row_number()) %>% 
@@ -101,14 +119,14 @@ weights_plot <- function(x, penalty = x$penalty$penalty, n = Inf) {
   } else {
     dat <- 
       dat %>% 
-      dplyr::arrange(weight) %>% 
+      dplyr::arrange(abs(weight)) %>% 
       dplyr::mutate(member = dplyr::row_number())
   }
   p <- 
     ggplot2::ggplot(dat, ggplot2::aes(x = weight, y = format(member), fill = model)) + 
     ggplot2::geom_bar(stat = "identity") + 
     ggplot2::ylab("Member") + 
-    ggplot2::ggtitle(paste("penalty =", format(x$coefs$spec$args$penalty, digits = 3))) + 
+    ggplot2::ggtitle(paste("penalty =", format(x$coefs$spec$args$penalty, digits = 3, scientific = FALSE))) + 
     ggplot2::geom_vline(xintercept = 0) + 
     ggplot2::xlab("Stacking Coefficient")
   
