@@ -25,7 +25,8 @@ check_inherits <- function(x, what) {
 # the `helper_data.Rda` contains data objects for use in unit testing.
 # due to its size, it's not included in the built package.
 # * when running locally, use the local helper_data. 
-# * when testing on github, download the hard-linked file from the relevant branch.
+# * when testing on a continuous integration platform, locate the helper_data 
+#   file in the appropriate reference environment
 # * when on cran, only run the tests in test_cran that don't require the data.
 
 get_current_branch <- function() {
@@ -46,16 +47,5 @@ on_cran <- function() {
   !identical(Sys.getenv("NOT_CRAN"), "true")
 }
 
-dl_mode <- if (identical(.Platform$OS.type, "windows")) {"wb"} else {"w"}
-
-if (on_github()) {
-  download.file(
-    paste0(
-      "https://github.com/tidymodels/stacks/blob/", 
-      get_current_branch(), 
-      "/tests/testthat/helper_data.Rda?raw=true"
-    ),
-    destfile = paste0(test_path(), "/helper_data.Rda"),
-    mode = dl_mode
-  )
-}
+# robustly test for prompt outputs without line breaks
+options(width = 1000)
